functor NL_LexFun(structure Absyn: ABSYN
                           structure Tokens: NL__TOKENS
                              sharing type Absyn.set = Tokens.set 
                           structure Interface: INTERFACE) : LEXER  = struct

    structure yyInput : sig

        type stream
	val mkStream : (int -> string) -> stream
	val fromStream : TextIO.StreamIO.instream -> stream
	val getc : stream -> (Char.char * stream) option
	val getpos : stream -> int
	val getlineNo : stream -> int
	val subtract : stream * stream -> string
	val eof : stream -> bool
	val lastWasNL : stream -> bool

      end = struct

        structure TIO = TextIO
        structure TSIO = TIO.StreamIO
	structure TPIO = TextPrimIO

        datatype stream = Stream of {
            strm : TSIO.instream,
	    id : int,  (* track which streams originated 
			* from the same stream *)
	    pos : int,
	    lineNo : int,
	    lastWasNL : bool
          }

	local
	  val next = ref 0
	in
	fun nextId() = !next before (next := !next + 1)
	end

	val initPos = 2 (* ml-lex bug compatibility *)

	fun mkStream inputN = let
              val strm = TSIO.mkInstream 
			   (TPIO.RD {
			        name = "lexgen",
				chunkSize = 4096,
				readVec = SOME inputN,
				readArr = NONE,
				readVecNB = NONE,
				readArrNB = NONE,
				block = NONE,
				canInput = NONE,
				avail = (fn () => NONE),
				getPos = NONE,
				setPos = NONE,
				endPos = NONE,
				verifyPos = NONE,
				close = (fn () => ()),
				ioDesc = NONE
			      }, "")
	      in 
		Stream {strm = strm, id = nextId(), pos = initPos, lineNo = 1,
			lastWasNL = true}
	      end

	fun fromStream strm = Stream {
		strm = strm, id = nextId(), pos = initPos, lineNo = 1, lastWasNL = true
	      }

	fun getc (Stream {strm, pos, id, lineNo, ...}) = (case TSIO.input1 strm
              of NONE => NONE
	       | SOME (c, strm') => 
		   SOME (c, Stream {
			        strm = strm', 
				pos = pos+1, 
				id = id,
				lineNo = lineNo + 
					 (if c = #"\n" then 1 else 0),
				lastWasNL = (c = #"\n")
			      })
	     (* end case*))

	fun getpos (Stream {pos, ...}) = pos

	fun getlineNo (Stream {lineNo, ...}) = lineNo

	fun subtract (new, old) = let
	      val Stream {strm = strm, pos = oldPos, id = oldId, ...} = old
	      val Stream {pos = newPos, id = newId, ...} = new
              val (diff, _) = if newId = oldId andalso newPos >= oldPos
			      then TSIO.inputN (strm, newPos - oldPos)
			      else raise Fail 
				"BUG: yyInput: attempted to subtract incompatible streams"
	      in 
		diff 
	      end

	fun eof s = not (isSome (getc s))

	fun lastWasNL (Stream {lastWasNL, ...}) = lastWasNL

      end

    datatype yystart_state = 
INITIAL
    structure UserDeclarations = 
      struct

structure T = Tokens
structure I = Interface
structure A = Absyn

open I

type pos = I.pos
type svalue = T.svalue
type ('a,'b) token = ('a,'b) T.token
type lexresult = (svalue,pos) token list * string

fun eof() = ([T.EOF(!line,!line)],"")

fun PN(s:string) = ([T.PN(A.ConS s,!line,!line)],s)
fun CNn s t = ([T.CNn(A.ConS s,!line,!line)],t)
fun CNg s t = ([T.CNg(A.ConS s,!line,!line)],t)
fun CNd s t = ([T.CNd(A.ConS s,!line,!line)],t)
fun CNa s t = ([T.CNa(A.ConS s,!line,!line)],t)
fun RNn s t = ([T.RNn(A.ConR s,!line,!line)],t)
fun RNg s t = ([T.RNg(A.ConR s,!line,!line)],t)
fun RNd s t = ([T.RNd(A.ConR s,!line,!line)],t)
fun RNa s t = ([T.RNa(A.ConR s,!line,!line)],t)
fun IVs(s:string) = ([T.IVs(A.ConS s,!line,!line)],s)
fun IVp(s:string) = ([T.IVp(A.ConS s,!line,!line)],s)
fun TVs(s:string) = ([T.TVs(A.ConR s,!line,!line)],s)
fun TVp(s:string) = ([T.TVp(A.ConR s,!line,!line)],s)
fun CA(s:string) = ([T.CA(A.ConS s,!line,!line)],s)
fun P(s:string) = ([T.P(A.ConR s,!line,!line)],s)



      end

    datatype yymatch 
      = yyNO_MATCH
      | yyMATCH of yyInput.stream * action * yymatch
    withtype action = yyInput.stream * yymatch -> UserDeclarations.lexresult

    local

    val yytable = 
#[([(#"\^@",#"\b",1),
(#"\v",#"\^_",1),
(#"!",#"-",1),
(#"/",#"@",1),
(#"C",#"C",1),
(#"G",#"G",1),
(#"L",#"L",1),
(#"O",#"Q",1),
(#"T",#"`",1),
(#"b",#"c",1),
(#"f",#"f",1),
(#"h",#"h",1),
(#"m",#"r",1),
(#"u",#"u",1),
(#"w",#"\255",1),
(#"\t",#"\t",2),
(#" ",#" ",2),
(#"\n",#"\n",3),
(#".",#".",4),
(#"A",#"A",5),
(#"B",#"B",6),
(#"D",#"D",7),
(#"E",#"E",8),
(#"F",#"F",9),
(#"H",#"H",10),
(#"I",#"I",11),
(#"J",#"J",12),
(#"K",#"K",13),
(#"M",#"M",14),
(#"N",#"N",15),
(#"R",#"R",16),
(#"S",#"S",17),
(#"a",#"a",18),
(#"d",#"d",19),
(#"e",#"e",20),
(#"g",#"g",21),
(#"i",#"i",22),
(#"j",#"j",23),
(#"k",#"k",24),
(#"l",#"l",25),
(#"s",#"s",26),
(#"t",#"t",27),
(#"v",#"v",28)], [0]), ([], [72]), ([(#"\t",#"\t",190),
(#" ",#" ",190)], [0, 72]), ([], [1]), ([], [2, 72]), ([(#"l",#"l",88),
(#"n",#"n",187)], [72]), ([(#"r",#"r",181)], [72]), ([(#"i",#"i",176)], [72]), ([(#"i",#"i",73),
(#"m",#"m",173)], [72]), ([(#"r",#"r",170)], [72]), ([(#"a",#"a",156),
(#"u",#"u",157)], [72]), ([(#"t",#"t",150)], [72]), ([(#"e",#"e",145)], [72]), ([(#"e",#"e",144)], [72]), ([(#"a",#"a",132)], [72]), ([(#"a",#"a",124)], [72]), ([(#"o",#"o",122)], [72]), ([(#"c",#"c",100),
(#"p",#"p",101),
(#"t",#"t",102)], [72]), ([(#"l",#"l",88),
(#"r",#"r",89)], [72]), ([(#"a",#"a",80),
(#"e",#"e",81),
(#"i",#"i",82)], [72]), ([(#"i",#"i",73)], [72]), ([(#"e",#"e",68)], [72]), ([(#"n",#"n",65),
(#"s",#"s",66)], [72]), ([(#"e",#"e",59)], [72]), ([(#"e",#"e",46)], [72]), ([(#"i",#"i",40)], [72]), ([(#"i",#"i",37)], [72]), ([(#"a",#"a",31)], [72]), ([(#"o",#"o",29)], [72]), ([(#"n",#"n",30)], []), ([], [5]), ([(#"n",#"n",32)], []), ([(#"z",#"z",33)], []), ([(#"e",#"e",34),
(#"t",#"t",35)], []), ([(#"n",#"n",36)], []), ([], [71]), ([], [70]), ([(#"n",#"n",38)], []), ([(#"d",#"d",39)], []), ([], [4]), ([(#"e",#"e",41)], []), ([(#"b",#"b",42)], []), ([(#"e",#"e",43),
(#"t",#"t",44)], []), ([(#"n",#"n",45)], []), ([], [69]), ([], [68]), ([(#"i",#"i",47),
(#"n",#"n",48)], []), ([(#"n",#"n",53)], []), ([(#"n",#"n",49)], []), ([(#"e",#"e",50),
(#"t",#"t",51)], []), ([(#"n",#"n",52)], []), ([], [67]), ([], [66]), ([(#"e",#"e",54)], [14, 17]), ([(#"m",#"m",55),
(#"n",#"n",56),
(#"r",#"r",57),
(#"s",#"s",58)], [14, 17]), ([], [16]), ([], [17]), ([], [15, 16]), ([], [15]), ([(#"d",#"d",60)], []), ([(#"e",#"e",61)], []), ([(#"m",#"m",62),
(#"r",#"r",63),
(#"s",#"s",64)], [18, 21]), ([], [20]), ([], [18, 19, 20, 21]), ([], [18, 19, 21]), ([], [63]), ([(#"t",#"t",67)], []), ([], [3]), ([(#"s",#"s",69)], []), ([(#"u",#"u",70)], []), ([(#"n",#"n",71)], []), ([(#"d",#"d",72)], []), ([], [62]), ([(#"n",#"n",74)], []), ([(#"e",#"e",75)], [10, 13]), ([(#"m",#"m",76),
(#"n",#"n",77),
(#"r",#"r",78),
(#"s",#"s",79)], [10, 13]), ([], [12]), ([], [13]), ([], [11, 12]), ([], [11]), ([(#"s",#"s",83)], []), ([(#"m",#"m",84),
(#"n",#"n",85),
(#"r",#"r",86),
(#"s",#"s",87)], []), ([(#"e",#"e",83)], []), ([], [6, 9]), ([], [8]), ([], [9]), ([], [6, 7, 8]), ([], [7]), ([(#"l",#"l",97)], []), ([(#"b",#"b",90)], []), ([(#"e",#"e",91)], []), ([(#"i",#"i",92)], []), ([(#"t",#"t",93)], []), ([(#"e",#"e",94)], []), ([(#"n",#"n",95),
(#"t",#"t",96)], []), ([], [64]), ([], [65]), ([(#"e",#"e",98)], []), ([(#"n",#"n",62),
(#"r",#"r",99)], [18, 21]), ([], [19]), ([(#"h",#"h",115)], []), ([(#"a",#"a",110)], []), ([(#"u",#"u",103)], []), ([(#"d",#"d",104)], []), ([(#"e",#"e",105)], []), ([(#"n",#"n",106)], []), ([(#"t",#"t",107)], []), ([(#"e",#"e",108)], [42]), ([(#"n",#"n",109)], []), ([], [43, 44, 45]), ([(#"n",#"n",111)], []), ([(#"i",#"i",112)], []), ([(#"e",#"e",113)], []), ([(#"n",#"n",114)], []), ([], [29]), ([(#"w",#"w",116)], []), ([(#"e",#"e",117)], []), ([(#"s",#"s",118)], []), ([(#"t",#"t",119)], []), ([(#"e",#"e",120)], []), ([(#"r",#"r",121)], []), ([], [50, 51, 52, 53]), ([(#"m",#"m",123)], []), ([], [26]), ([(#"c",#"c",125)], []), ([(#"h",#"h",126)], []), ([(#"b",#"b",127)], []), ([(#"a",#"a",128)], []), ([(#"r",#"r",129)], []), ([(#"n",#"n",130),
(#"s",#"s",131)], [54]), ([], [56, 57]), ([], [55]), ([(#"d",#"d",133),
(#"n",#"n",134),
(#"r",#"r",135)], []), ([(#"r",#"r",141)], []), ([(#"n",#"n",138)], []), ([(#"i",#"i",136)], []), ([(#"a",#"a",137)], []), ([], [25]), ([(#"e",#"e",139)], [30, 32, 33]), ([(#"s",#"s",140)], []), ([], [31]), ([(#"i",#"i",142)], []), ([(#"d",#"d",143)], []), ([], [27]), ([(#"i",#"i",47)], []), ([(#"d",#"d",146)], []), ([(#"e",#"e",147)], []), ([(#"m",#"m",62),
(#"n",#"n",148),
(#"r",#"r",149),
(#"s",#"s",64)], [18, 21]), ([], [21]), ([], [18, 19, 20]), ([(#"a",#"a",151)], []), ([(#"l",#"l",152)], []), ([(#"i",#"i",153)], []), ([(#"e",#"e",154)], []), ([(#"n",#"n",155)], []), ([], [28]), ([(#"u",#"u",162)], []), ([(#"n",#"n",158)], []), ([(#"d",#"d",159)], []), ([(#"e",#"e",160)], [38, 40, 41]), ([(#"s",#"s",161)], []), ([], [39]), ([(#"p",#"p",163)], []), ([(#"t",#"t",164)], []), ([(#"s",#"s",165)], []), ([(#"t",#"t",166)], []), ([(#"a",#"a",167)], []), ([(#"d",#"d",168)], []), ([(#"t",#"t",169)], []), ([], [58, 59, 60, 61]), ([(#"a",#"a",171)], []), ([(#"u",#"u",172)], []), ([], [34, 35, 36, 37]), ([(#"i",#"i",174)], []), ([(#"l",#"l",175)], []), ([], [24]), ([(#"e",#"e",177)], []), ([(#"t",#"t",178)], []), ([(#"e",#"e",179)], []), ([(#"r",#"r",180)], []), ([], [23]), ([(#"u",#"u",182)], []), ([(#"d",#"d",183)], []), ([(#"e",#"e",184)], []), ([(#"r",#"r",185)], []), ([(#"s",#"s",186)], [46, 48, 49]), ([], [47]), ([(#"n",#"n",188)], []), ([(#"a",#"a",189)], []), ([], [22]), ([(#"\t",#"\t",190),
(#" ",#" ",190)], [0])]
    fun mk yyins = let
        (* current start state *)
        val yyss = ref INITIAL
	fun YYBEGIN ss = (yyss := ss)
	(* current input stream *)
        val yystrm = ref yyins
	(* get one char of input *)
	val yygetc = yyInput.getc
	(* create yytext *)
	fun yymktext(strm) = yyInput.subtract (strm, !yystrm)
        open UserDeclarations
        fun lex 
(yyarg as ()) = let 
     fun continue() = let
            val yylastwasn = yyInput.lastWasNL (!yystrm)
            fun yystuck (yyNO_MATCH) = raise Fail "stuck state"
	      | yystuck (yyMATCH (strm, action, old)) = 
		  action (strm, old)
	    val yypos = yyInput.getpos (!yystrm)
	    val yygetlineNo = yyInput.getlineNo
	    fun yyactsToMatches (strm, [],	  oldMatches) = oldMatches
	      | yyactsToMatches (strm, act::acts, oldMatches) = 
		  yyMATCH (strm, act, yyactsToMatches (strm, acts, oldMatches))
	    fun yygo actTable = 
		(fn (~1, _, oldMatches) => yystuck oldMatches
		  | (curState, strm, oldMatches) => let
		      val (transitions, finals') = Vector.sub (yytable, curState)
		      val finals = map (fn i => Vector.sub (actTable, i)) finals'
		      fun tryfinal() = 
		            yystuck (yyactsToMatches (strm, finals, oldMatches))
		      fun find (c, []) = NONE
			| find (c, (c1, c2, s)::ts) = 
		            if c1 <= c andalso c <= c2 then SOME s
			    else find (c, ts)
		      in case yygetc strm
			  of SOME(c, strm') => 
			       (case find (c, transitions)
				 of NONE => tryfinal()
				  | SOME n => 
				      yygo actTable
					(n, strm', 
					 yyactsToMatches (strm, finals, oldMatches)))
			   | NONE => tryfinal()
		      end)
	    in 
let
fun yyAction0 (strm, lastMatch : yymatch) = (yystrm := strm; (lex()))
fun yyAction1 (strm, lastMatch : yymatch) = (yystrm := strm;
      (next_line(); lex()))
fun yyAction2 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.PUNKT(!line,!line)],yytext)
      end
fun yyAction3 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.CopVs(!line,!line)],yytext)
      end
fun yyAction4 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.CopVp(!line,!line)],yytext)
      end
fun yyAction5 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.von(!line,!line)],yytext)
      end
fun yyAction6 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.Detn(!line,!line)],yytext)
      end
fun yyAction7 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.Detg(!line,!line)],yytext)
      end
fun yyAction8 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.Detd(!line,!line)],yytext)
      end
fun yyAction9 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.Deta(!line,!line)],yytext)
      end
fun yyAction10 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.EQn(!line,!line)],yytext)
      end
fun yyAction11 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.EQg(!line,!line)],yytext)
      end
fun yyAction12 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.EQd(!line,!line)],yytext)
      end
fun yyAction13 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.EQa(!line,!line)],yytext)
      end
fun yyAction14 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.NQn(!line,!line)],yytext)
      end
fun yyAction15 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.NQg(!line,!line)],yytext)
      end
fun yyAction16 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.NQd(!line,!line)],yytext)
      end
fun yyAction17 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.NQa(!line,!line)],yytext)
      end
fun yyAction18 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.UQn(!line,!line)],yytext)
      end
fun yyAction19 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.UQg(!line,!line)],yytext)
      end
fun yyAction20 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.UQd(!line,!line)],yytext)
      end
fun yyAction21 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; ([T.UQa(!line,!line)],yytext)
      end
fun yyAction22 (strm, lastMatch : yymatch) = (yystrm := strm; (PN "Anna"))
fun yyAction23 (strm, lastMatch : yymatch) = (yystrm := strm; (PN "Dieter"))
fun yyAction24 (strm, lastMatch : yymatch) = (yystrm := strm; (PN "Emil"))
fun yyAction25 (strm, lastMatch : yymatch) = (yystrm := strm; (PN "Maria"))
fun yyAction26 (strm, lastMatch : yymatch) = (yystrm := strm; (PN "Rom"))
fun yyAction27 (strm, lastMatch : yymatch) = (yystrm := strm; (PN "Madrid"))
fun yyAction28 (strm, lastMatch : yymatch) = (yystrm := strm; (PN "Italien"))
fun yyAction29 (strm, lastMatch : yymatch) = (yystrm := strm; (PN "Spanien"))
fun yyAction30 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CNn "Mann" yytext)
      end
fun yyAction31 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CNg "Mann" yytext)
      end
fun yyAction32 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CNd "Mann" yytext)
      end
fun yyAction33 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CNa "Mann" yytext)
      end
fun yyAction34 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CNn "Frau" yytext)
      end
fun yyAction35 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CNg "Frau" yytext)
      end
fun yyAction36 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CNd "Frau" yytext)
      end
fun yyAction37 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CNa "Frau" yytext)
      end
fun yyAction38 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CNn "Hund" yytext)
      end
fun yyAction39 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CNg "Hund" yytext)
      end
fun yyAction40 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CNd "Hund" yytext)
      end
fun yyAction41 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CNa "Hund" yytext)
      end
fun yyAction42 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CNn "Student" yytext)
      end
fun yyAction43 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CNg "Student" yytext)
      end
fun yyAction44 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CNd "Student" yytext)
      end
fun yyAction45 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (CNa "Student" yytext)
      end
fun yyAction46 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (RNn "Bruder" yytext)
      end
fun yyAction47 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (RNg "Bruder" yytext)
      end
fun yyAction48 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (RNd "Bruder" yytext)
      end
fun yyAction49 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (RNa "Bruder" yytext)
      end
fun yyAction50 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (RNn "Schwester" yytext)
      end
fun yyAction51 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (RNg "Schwester" yytext)
      end
fun yyAction52 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (RNd "Schwester" yytext)
      end
fun yyAction53 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (RNa "Schwester" yytext)
      end
fun yyAction54 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (RNn "Nachbar" yytext)
      end
fun yyAction55 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (RNg "Nachbar" yytext)
      end
fun yyAction56 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (RNd "Nachbar" yytext)
      end
fun yyAction57 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (RNa "Nachbar" yytext)
      end
fun yyAction58 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (RNn "Hauptstadt" yytext)
      end
fun yyAction59 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (RNg "Hauptstadt" yytext)
      end
fun yyAction60 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (RNd "Hauptstadt" yytext)
      end
fun yyAction61 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm; (RNa "Hauptstadt" yytext)
      end
fun yyAction62 (strm, lastMatch : yymatch) = (yystrm := strm; (CA "gesund"))
fun yyAction63 (strm, lastMatch : yymatch) = (yystrm := strm; (P "in"))
fun yyAction64 (strm, lastMatch : yymatch) = (yystrm := strm; (IVp "arbeiten"))
fun yyAction65 (strm, lastMatch : yymatch) = (yystrm := strm; (IVs "arbeiten"))
fun yyAction66 (strm, lastMatch : yymatch) = (yystrm := strm; (TVp "kennen"))
fun yyAction67 (strm, lastMatch : yymatch) = (yystrm := strm; (TVs "kennen"))
fun yyAction68 (strm, lastMatch : yymatch) = (yystrm := strm; (TVp "lieben"))
fun yyAction69 (strm, lastMatch : yymatch) = (yystrm := strm; (TVs "lieben"))
fun yyAction70 (strm, lastMatch : yymatch) = (yystrm := strm; (TVp "tanzen"))
fun yyAction71 (strm, lastMatch : yymatch) = (yystrm := strm; (TVs "tanzen"))
fun yyAction72 (strm, lastMatch : yymatch) = let
      val yytext = yymktext(strm)
      in
        yystrm := strm;
        (error ("ignoring illegal character " ^ yytext,
                      !line,!line); lex())
      end
val yyactTable = Vector.fromList([yyAction0, yyAction1, yyAction2, yyAction3,
  yyAction4, yyAction5, yyAction6, yyAction7, yyAction8, yyAction9, yyAction10,
  yyAction11, yyAction12, yyAction13, yyAction14, yyAction15, yyAction16,
  yyAction17, yyAction18, yyAction19, yyAction20, yyAction21, yyAction22,
  yyAction23, yyAction24, yyAction25, yyAction26, yyAction27, yyAction28,
  yyAction29, yyAction30, yyAction31, yyAction32, yyAction33, yyAction34,
  yyAction35, yyAction36, yyAction37, yyAction38, yyAction39, yyAction40,
  yyAction41, yyAction42, yyAction43, yyAction44, yyAction45, yyAction46,
  yyAction47, yyAction48, yyAction49, yyAction50, yyAction51, yyAction52,
  yyAction53, yyAction54, yyAction55, yyAction56, yyAction57, yyAction58,
  yyAction59, yyAction60, yyAction61, yyAction62, yyAction63, yyAction64,
  yyAction65, yyAction66, yyAction67, yyAction68, yyAction69, yyAction70,
  yyAction71, yyAction72])
in
  if yyInput.eof(!(yystrm))
    then UserDeclarations.eof(yyarg)
    else (case (!(yyss))
       of INITIAL => yygo yyactTable (0, !(yystrm), yyNO_MATCH)
      (* end case *))
end
            end
	  in 
            continue() 	  
	    handle IO.Io{cause, ...} => raise cause
          end
        in 
          lex 
        end
    in
    fun makeLexer yyinputN = mk (yyInput.mkStream yyinputN)
    fun makeLexer' ins = mk (yyInput.mkStream ins)
    end

  end
